# Murmur examples

The examples work with simple agents and tools for demonstration purposes. You will need to build and publish them first before you can run any of the examples. 

- [Getting Started with Examples](https://murmur-nexus.github.io/murmur/tutorial/getting-started-with-examples/)
